pub struct ThreadPoolLite {
pub thread: TaskExecutor,
}Expand description
Simple thread pool Used for quickly submitting tasks Only one thread, bound to only one core 简易线程池 用于快速提交任务 只有一个线程, 只绑定一个核心
Fields
thread: TaskExecutorImplementations